@@ -5,6 +5,7 @@ from .alive import *
 from .archive import *
 from .baidu import *
 from .bandcamp import *
+from .bigthink import *
 from .bilibili import *
 from .cbs import *
 from .ckplayer import *
@@ -79,3 +80,4 @@ from .youku import *
 from .youtube import *
 from .ted import *
 from .khan import *
+from .zhanqi import *
